@@ -17,13 +17,18 @@
 #'   variables are manipulated. Can also be a character vector of observed
 #'   (non-manipulated) variables, in which case generalized Eta Squared is
 #'   calculated taking these observed variables into account. For `afex_aov`
-#'   model, `generalized = TRUE`, the observed variables are extracted
+#'   model, when `generalized = TRUE`, the observed variables are extracted
 #'   automatically from the fitted model, if they were provided then.
 #' @inheritParams chisq_to_phi
-#' @param ... For Bayesian models, passed to `ss_function`. Otherwise ignored.
+#' @inheritParams standardize
+#' @param ... Arguments passed to or from other methods.
+#'   - Can be `include_intercept = TRUE` to include the effect size for the intercept.
+#'   - For Bayesian models, arguments passed to `ss_function`.
 #'
 #' @return
-#' A data frame with the effect size(s) and confidence interval(s).
+#' A data frame with the effect size(s) between 0-1 (`Eta2`, `Epsilon2`,
+#' `Omega2`, `Cohens_f` or `Cohens_f2`, possibly with the `partial` or
+#' `generalized` suffix), and their CIs (`CI_low` and `CI_high`).
 #' \cr\cr
 #' For `eta_squared_posterior()`, a data frame containing the ppd of the Eta
 #' squared for each fixed effect, which can then be passed to
@@ -57,6 +62,10 @@
 #' Though Omega is the more popular choice (Albers \& Lakens, 2018), Epsilon is
 #' analogous to adjusted R2 (Allen, 2017, p. 382), and has been found to be less
 #' biased (Carroll & Nordholm, 1975).
+#' \cr\cr
+#' (Note that for \eqn{\omega_p^2} and \eqn{\epsilon_p^2} it is possible to
+#' compute a negative number; even though this doesn't make any practical sense,
+#' it is recommended to report the negative number and not a 0.)
 #'
 #' ## Cohen's f
 #' Cohen's f can take on values between zero, when the population means are all
@@ -64,8 +73,8 @@
 #' increases relative to the average standard deviation within each group.
 #' \cr\cr
 #' When comparing two models in a sequential regression analysis, Cohen's f for
-#' R-square change is the ratio between ratio between the increase in R-square
-#' and the \% unexplained variance.
+#' R-square change is the ratio between the increase in R-square
+#' and the percent of unexplained variance.
 #' \cr\cr
 #' Cohen has suggested that the values of 0.10, 0.25, and 0.40 represent small,
 #' medium, and large effect sizes, respectively.
@@ -79,8 +88,8 @@
 #' effect size in the sample data). See [rstantools::posterior_predict()] for
 #' more info.
 #'
-#' @inheritSection cohens_d Confidence Intervals
-#' @inheritSection chisq_to_phi CI Contains Zero
+#' @inheritSection effectsize-CIs Confidence Intervals
+#' @inheritSection effectsize-CIs CI Contains Zero
 #'
 #'
 #' @seealso [F_to_eta2()]
@@ -106,8 +115,12 @@
 #' model0 <- aov(mpg ~ am_f + cyl_f, data = mtcars) # no interaction
 #' cohens_f_squared(model0, model2 = model)
 #'
+#' ## Interpretation of effect sizes
+#' ## -------------------------------------
 #'
-#'
+#' interpret_omega_squared(0.15, rules = "field2013")
+#' interpret_eta_squared(0.15, rules = "cohen1992")
+#' interpret_epsilon_squared(0.15, rules = "cohen1992")
 #'
 #' # Recommended: Type-3 effect sizes + effects coding
 #' # -------------------------------------------------
@@ -150,6 +163,7 @@
 #'
 #' ## Bayesian Models (PPD)
 #' ## ---------------------
+#' \dontrun{
 #' if (require(rstanarm) && require(bayestestR) && require(car)) {
 #'   fit_bayes <- stan_glm(mpg ~ factor(cyl) * wt + qsec,
 #'     data = mtcars,
@@ -171,26 +185,50 @@
 #'   eta_squared(aov_table)
 #' }
 #' }
+#' }
 #'
-#' @return A data frame containing the effect size values and their confidence intervals.
-#'
+#' @return A data frame containing the effect size values and their confidence
+#'   intervals.
 #'
 #' @references
-#' - Albers, C., \& Lakens, D. (2018). When power analyses based on pilot data are biased: Inaccurate effect size estimators and follow-up bias. Journal of experimental social psychology, 74, 187-195.
-#' - Allen, R. (2017). Statistics and Experimental Design for Psychologists: A Model Comparison Approach. World Scientific Publishing Company.
-#' - Carroll, R. M., & Nordholm, L. A. (1975). Sampling Characteristics of Kelley's epsilon and Hays' omega. Educational and Psychological Measurement, 35(3), 541-554.
-#' - Kelley, T. (1935) An unbiased correlation ratio measure. Proceedings of the National Academy of Sciences. 21(9). 554-559.
-#' - Morey, R. D., Hoekstra, R., Rouder, J. N., Lee, M. D., & Wagenmakers, E. J. (2016). The fallacy of placing confidence in confidence intervals. Psychonomic bulletin & review, 23(1), 103-123.
-#' - Olejnik, S., & Algina, J. (2003). Generalized eta and omega squared statistics: measures of effect size for some common research designs. Psychological methods, 8(4), 434.
-#' - Steiger, J. H. (2004). Beyond the F test: Effect size confidence intervals and tests of close fit in the analysis of variance and contrast analysis. Psychological Methods, 9, 164-182.
+#' - Albers, C., \& Lakens, D. (2018). When power analyses based on pilot data
+#' are biased: Inaccurate effect size estimators and follow-up bias. Journal of
+#' experimental social psychology, 74, 187-195.
+#'
+#' - Allen, R. (2017). Statistics and Experimental Design for Psychologists: A
+#' Model Comparison Approach. World Scientific Publishing Company.
+#'
+#' - Carroll, R. M., & Nordholm, L. A. (1975). Sampling Characteristics of
+#' Kelley's epsilon and Hays' omega. Educational and Psychological Measurement,
+#' 35(3), 541-554.
+#'
+#' - Kelley, T. (1935) An unbiased correlation ratio measure. Proceedings of the
+#' National Academy of Sciences. 21(9). 554-559.
+#'
+#' - Olejnik, S., & Algina, J. (2003). Generalized eta and omega squared
+#' statistics: measures of effect size for some common research designs.
+#' Psychological methods, 8(4), 434.
+#'
+#' - Steiger, J. H. (2004). Beyond the F test: Effect size confidence intervals
+#' and tests of close fit in the analysis of variance and contrast analysis.
+#' Psychological Methods, 9, 164-182.
 #'
 #' @export
 eta_squared <- function(model,
                         partial = TRUE,
                         generalized = FALSE,
                         ci = 0.9,
+                        verbose = TRUE,
                         ...) {
-  out <- .anova_es(model, type = "eta", partial = partial, generalized = generalized, ci = ci)
+  out <- .anova_es(
+    model,
+    type = "eta",
+    partial = partial,
+    generalized = generalized,
+    ci = ci,
+    verbose = verbose,
+    ...
+  )
   class(out) <- unique(c("effectsize_table", "see_effectsize_table", class(out)))
   return(out)
 }
@@ -200,8 +238,9 @@ eta_squared <- function(model,
 omega_squared <- function(model,
                           partial = TRUE,
                           ci = 0.9,
+                          verbose = TRUE,
                           ...) {
-  out <- .anova_es(model, type = "omega", partial = partial, ci = ci)
+  out <- .anova_es(model, type = "omega", partial = partial, ci = ci, verbose = verbose, ...)
   class(out) <- unique(c("effectsize_table", "see_effectsize_table", class(out)))
   return(out)
 }
@@ -211,8 +250,9 @@ omega_squared <- function(model,
 epsilon_squared <- function(model,
                             partial = TRUE,
                             ci = 0.9,
+                            verbose = TRUE,
                             ...) {
-  out <- .anova_es(model, type = "epsilon", partial = partial, ci = ci)
+  out <- .anova_es(model, type = "epsilon", partial = partial, ci = ci, verbose = verbose, ...)
   class(out) <- unique(c("effectsize_table", "see_effectsize_table", class(out)))
   return(out)
 }
@@ -223,14 +263,17 @@ epsilon_squared <- function(model,
 #'   returns the effect size for R-squared-change between the two models.
 #' @export
 cohens_f <- function(model, partial = TRUE, ci = 0.9, squared = FALSE,
+                     verbose = TRUE,
                      model2 = NULL, ...) {
   if (!is.null(model2)) {
-    return(.cohens_f_delta(model, model2, ci = ci, squared = squared))
+    return(.cohens_f_delta(model, model2, ci = ci, squared = squared, verbose = verbose))
   }
 
   res <- eta_squared(model,
     partial = partial,
-    ci = ci
+    ci = ci,
+    verbose = verbose,
+    ...
   )
 
   if ("Eta2_partial" %in% colnames(res)) {
@@ -261,11 +304,47 @@ cohens_f <- function(model, partial = TRUE, ci = 0.9, squared = FALSE,
 #' @rdname eta_squared
 #' @export
 cohens_f_squared <- function(model, partial = TRUE, ci = 0.9, squared = TRUE,
+                             verbose = TRUE,
                              model2 = NULL, ...) {
-  cohens_f(model, partial = partial, ci = ci, squared = squared, model2 = model2)
+  cohens_f(
+    model,
+    partial = partial,
+    ci = ci,
+    squared = squared,
+    verbose = verbose,
+    model2 = model2,
+    ...
+  )
 }
 
 
+#' @keywords internal
+#' @importFrom insight model_info
+.cohens_f_delta <- function(model, model2, ci = 0.9, squared = FALSE, verbose = TRUE) {
+  # check
+  if (!inherits(model, "lm") ||
+      !inherits(model2, "lm") ||
+      !insight::model_info(model)$is_linear ||
+      !insight::model_info(model2)$is_linear) {
+    stop("Cohen's f for R2-change only supported for fixed effect linear models.",
+         call. = FALSE
+    )
+  }
+
+  # Anova
+  ANOVA <- anova(model, model2)
+  out <- F_to_f(ANOVA[2, "F"], abs(ANOVA[2, "Df"]), min(ANOVA["Res.Df"]),
+                ci = ci, squared = squared
+  )
+
+  if (requireNamespace("performance")) {
+    R2d <- performance::r2(model)[[1]] - performance::r2(model2)[[1]]
+    out$R2_delta <- abs(R2d)
+  }
+
+  return(out)
+}
+
 # Get ES ------------------------------------------------------------------
 
 #' @keywords internal
@@ -275,6 +354,7 @@ cohens_f_squared <- function(model, partial = TRUE, ci = 0.9, squared = TRUE,
            partial = TRUE,
            generalized = FALSE,
            ci = 0.9,
+           verbose = TRUE,
            ...) {
     UseMethod(".anova_es")
   }
@@ -286,13 +366,15 @@ cohens_f_squared <- function(model, partial = TRUE, ci = 0.9, squared = TRUE,
                               partial = TRUE,
                               generalized = FALSE,
                               ci = 0.9,
+                              verbose = TRUE,
                               ...) {
   .anova_es.anova(
     stats::anova(model),
     type = type,
     partial = partial,
     generalized = generalized,
-    ci = ci
+    ci = ci,
+    verbose = verbose
   )
 }
 
@@ -304,6 +386,7 @@ cohens_f_squared <- function(model, partial = TRUE, ci = 0.9, squared = TRUE,
                           partial = TRUE,
                           generalized = FALSE,
                           ci = 0.9,
+                          verbose = TRUE,
                           ...) {
   if (!inherits(model, c("Gam", "anova"))) {
     # Pass to ANOVA table method
@@ -312,7 +395,9 @@ cohens_f_squared <- function(model, partial = TRUE, ci = 0.9, squared = TRUE,
       type = type,
       partial = partial,
       generalized = generalized,
-      ci = ci
+      ci = ci,
+      verbose = verbose,
+      ...
     )
     return(res)
   }
@@ -320,7 +405,7 @@ cohens_f_squared <- function(model, partial = TRUE, ci = 0.9, squared = TRUE,
   type <- match.arg(type)
 
   params <- as.data.frame(parameters::model_parameters(model))
-  .es_aov(params, type, partial, generalized, ci)
+  .es_aov(params, type, partial, generalized, ci, verbose = verbose, ...)
 }
 
 #' @keywords internal
@@ -329,8 +414,10 @@ cohens_f_squared <- function(model, partial = TRUE, ci = 0.9, squared = TRUE,
                     partial = TRUE,
                     generalized = FALSE,
                     ci = 0.9,
+                    verbose = TRUE,
+                    include_intercept = FALSE,
                     ...) {
-  params <- params[params$Parameter != "(Intercept)", ]
+
   if (!"Residuals" %in% params$Parameter) {
     stop(
       "No residuals data found - ",
@@ -339,17 +426,25 @@ cohens_f_squared <- function(model, partial = TRUE, ci = 0.9, squared = TRUE,
     )
   }
 
-  values <- .values_aov(params)
+  if (include_intercept) {
+    values <- .values_aov(params[params$Parameter != "(Intercept)", ])
+  } else {
+    params <- params[params$Parameter != "(Intercept)", ]
+    values <- .values_aov(params)
+  }
+
   df_error <- params$df[params$Parameter == "Residuals"]
   params <- params[params$Parameter != "Residuals", , drop = FALSE]
 
   if (nrow(params) == 1L &&
     (partial || isTRUE(generalized) || is.character(generalized))) {
-    txt_type <- ifelse(isTRUE(generalized) || is.character(generalized), "generalized", "partial")
-    message(
-      "For one-way between subjects designs, ", txt_type, " ", type, " squared is equvilant to ", type, " squared.\n",
-      "Returning ", type, " squared."
-    )
+    if (verbose) {
+      txt_type <- ifelse(isTRUE(generalized) || is.character(generalized), "generalized", "partial")
+      message(
+        "For one-way between subjects designs, ", txt_type, " ", type, " squared is equvilant to ", type, " squared.\n",
+        "Returning ", type, " squared."
+      )
+    }
     partial <- FALSE
   }
 
@@ -432,15 +527,153 @@ cohens_f_squared <- function(model, partial = TRUE, ci = 0.9, squared = TRUE,
     "CI", "CI_low", "CI_high"
   ), drop = FALSE]
 
+  attr(out, "partial") <- partial
+  attr(out, "generalized") <- generalized
+  attr(out, "ci") <- ci
+  attr(out, "ci_method") <- if (is.numeric(ci)) list(method = "ncp", distribution = "t")
   out
 }
 
-#' @keywords internal
 .anova_es.lm <- .anova_es.aov
 
-#' @keywords internal
 .anova_es.glm <- .anova_es.aov
 
+.anova_es.manova <- .anova_es.aov
+
+#' @keywords internal
+#' @importFrom parameters model_parameters
+#' @importFrom insight find_predictors
+.anova_es.aovlist <- function(model,
+                              type = c("eta", "omega", "epsilon"),
+                              partial = TRUE,
+                              generalized = FALSE,
+                              ci = 0.9,
+                              verbose = TRUE,
+                              include_intercept = FALSE,
+                              ...) {
+  type <- match.arg(type)
+
+  params <- as.data.frame(parameters::model_parameters(model))
+  if (!"Residuals" %in% params$Parameter) {
+    stop(
+      "No residuals data found - ",
+      type,
+      " squared can only be computed for simple `aov` models."
+    )
+  }
+
+  if (include_intercept) {
+    values <- .values_aov(params[params$Parameter != "(Intercept)", ])
+  } else {
+    params <- params[params$Parameter != "(Intercept)", ]
+    values <- .values_aov(params)
+  }
+
+  params <- params[params$Parameter != "Residuals" & !is.na(params$`F`), , drop = FALSE]
+  Sum_Squares_total <- sum(sapply(values, "[[", "Sum_Squares_total"))
+  Sum_Squares_residuals <- sapply(values[params$Group], "[[", "Sum_Squares_residuals")
+  Mean_Square_residuals <- sapply(values[params$Group], "[[", "Mean_Square_residuals")
+  df_residuals <- sapply(values[params$Group], "[[", "df_residuals")
+  ns <- sapply(values[params$Group], "[[", "n")
+
+
+  if (type == "eta") {
+    if (isTRUE(generalized) || is.character(generalized)) {
+      ## copied from afex
+      obs <- logical(nrow(params))
+      if (is.character(generalized)) {
+        for (o in generalized) {
+          oi <- grepl(paste0("\\b", o, "\\b"), params$Parameter)
+
+          if (!any(oi)) stop("Observed variable not in data: ", o, call. = FALSE)
+
+          obs <- obs | oi
+        }
+      }
+      obs_SSn1 <- sum(params$Sum_Squares * obs)
+      obs_SSn2 <- params$Sum_Squares * obs
+
+      params$Eta2_generalized <- params$Sum_Squares /
+        (params$Sum_Squares + sum(sapply(values, "[[", "Sum_Squares_residuals")) +
+           obs_SSn1 - obs_SSn2)
+    } else if (!isTRUE(partial)) {
+      params$Eta2 <- params$Sum_Squares / Sum_Squares_total
+    } else {
+      params$Eta2_partial <-
+        params$Sum_Squares /
+        (params$Sum_Squares + Sum_Squares_residuals)
+    }
+  } else if (type == "omega") {
+    SSS_values <- values[[which(names(values) %in% insight::find_predictors(model)[[1]])]]
+    is_within <- !params$Group %in% insight::find_predictors(model)[[1]]
+    Sum_Squares_Subjects <- SSS_values$Sum_Squares_residuals
+    Mean_Squares_Subjects <- SSS_values$Mean_Square_residuals
+
+    # implemented from https://www.jasonfinley.com/tools/OmegaSquaredQuickRef_JRF_3-31-13.pdf
+    if (!isTRUE(partial)) {
+      params$Omega2 <-
+        (params$Sum_Squares - params$df * Mean_Square_residuals) /
+        (Sum_Squares_total + Mean_Squares_Subjects)
+    } else {
+      params$Omega2_partial <-
+        (params$Sum_Squares - params$df * Mean_Square_residuals) /
+        (params$Sum_Squares + is_within * Sum_Squares_residuals +
+           Sum_Squares_Subjects + Mean_Squares_Subjects)
+    }
+  } else if (type == "epsilon") {
+    if (!isTRUE(partial)) {
+      params$Epsilon2 <-
+        (params$Sum_Squares - params$df * Mean_Square_residuals) /
+        Sum_Squares_total
+    } else {
+      params$Epsilon2_partial <-
+        (params$Sum_Squares - params$df * Mean_Square_residuals) /
+        (params$Sum_Squares + Sum_Squares_residuals)
+    }
+  }
+
+  out <- params
+
+  if (!is.null(ci)) {
+    # based on MBESS::ci.R2
+    ES <- pmax(0, out[[ncol(out)]])
+    f <- (ES / out$df) / ((1 - ES) / df_residuals)
+
+    out <- cbind(
+      out,
+      # This really is a generic F_to_R2
+      F_to_eta2(f,
+                out$df,
+                df_residuals,
+                ci = ci
+      )[-1]
+    )
+  }
+
+  out <- out[, colnames(out) %in% c(
+    "Group",
+    "Response",
+    "Parameter",
+    "Eta2_generalized",
+    "Eta2_partial",
+    "Omega2_partial",
+    "Epsilon2_partial",
+    "Eta2",
+    "Omega2",
+    "Epsilon2",
+    "CI",
+    "CI_low",
+    "CI_high"
+  ), drop = FALSE]
+  rownames(out) <- NULL
+
+  attr(out, "partial") <- partial
+  attr(out, "generalized") <- generalized
+  attr(out, "ci") <- ci
+  attr(out, "ci_method") <- if (is.numeric(ci)) list(method = "ncp", distribution = "t")
+  out
+}
+
 #' @keywords internal
 #' @importFrom stats aov
 #' @importFrom utils packageVersion
@@ -449,6 +682,7 @@ cohens_f_squared <- function(model, partial = TRUE, ci = 0.9, squared = TRUE,
                           partial = TRUE,
                           generalized = FALSE,
                           ci = 0.9,
+                          verbose = TRUE,
                           ...) {
   model <- stats::aov(model)
   params <- as.data.frame(parameters::model_parameters(model))
@@ -457,23 +691,30 @@ cohens_f_squared <- function(model, partial = TRUE, ci = 0.9, squared = TRUE,
     type = type,
     partial = partial,
     generalized = generalized,
-    ci = ci
+    ci = ci,
+    verbose = verbose,
+    ...
   )
   out <- do.call("rbind", params)
   rownames(out) <- NULL
+
+  attr(out, "partial") <- attr(params[[1]], "partial")
+  attr(out, "generalized") <- attr(params[[1]], "generalized")
+  attr(out, "ci") <- attr(params[[1]], "ci", exact = TRUE)
+  attr(out, "ci_method") <- attr(params[[1]], "ci_method", exact = TRUE)
   out
 }
 
 .anova_es.maov <- .anova_es.mlm
 
-.anova_es.manova <- .anova_es.aov
-
 #' @keywords internal
 .anova_es.anova <- function(model,
                             type = c("eta", "omega", "epsilon"),
                             partial = TRUE,
                             generalized = FALSE,
                             ci = 0.9,
+                            verbose = TRUE,
+                            include_intercept = FALSE,
                             ...) {
   type <- match.arg(type)
   es_fun <- switch(type,
@@ -483,8 +724,8 @@ cohens_f_squared <- function(model, partial = TRUE, ci = 0.9, squared = TRUE,
   )
 
   F_val <- c("F value", "approx F", "F-value")
-  numDF <- c("NumDF", "num Df", "numDF")
-  denDF <- c("DenDF", "den Df", "denDF")
+  numDF <- c("NumDF", "num Df", "numDF", "npar")
+  denDF <- c("DenDF", "den Df", "denDF", "df_error")
 
   if (!any(denDF %in% colnames(model))) {
     # Pass to AOV method
@@ -492,32 +733,37 @@ cohens_f_squared <- function(model, partial = TRUE, ci = 0.9, squared = TRUE,
       partial = partial,
       type = type,
       generalized = generalized,
-      ci = ci
+      ci = ci,
+      verbose = verbose,
+      include_intercept = include_intercept,
+      ...
     )
     return(res)
   }
-  model <- model[rownames(model) != "(Intercept)", ]
-  model <- model[rownames(model) != "Residuals", ]
+  if (!include_intercept) model <- model[rownames(model) != "(Intercept)", , drop = FALSE]
+  model <- model[rownames(model) != "Residuals", , drop = FALSE]
 
   F_val <- F_val[F_val %in% colnames(model)]
   numDF <- numDF[numDF %in% colnames(model)]
   denDF <- denDF[denDF %in% colnames(model)]
 
 
-  if (!isTRUE(partial)) {
+  if (verbose && !isTRUE(partial)) {
     warning(
       "Currently only supports partial ",
       type,
       " squared for this class of objects.",
       call. = FALSE
     )
+    partial <- TRUE
   }
 
-  if (isTRUE(generalized) || is.character(generalized)) {
+  if (verbose && (isTRUE(generalized) || is.character(generalized))) {
     warning(
       "generalized ", type, " squared ",
       "is not supported for this class of object."
     )
+    generalized <- FALSE
   }
 
   par_table <- as.data.frame(model)
@@ -531,6 +777,10 @@ cohens_f_squared <- function(model, partial = TRUE, ci = 0.9, squared = TRUE,
     )
   )
 
+  attr(out, "partial") <- partial
+  attr(out, "generalized") <- generalized
+  attr(out, "ci") <- ci
+  attr(out, "ci_method") <- if (is.numeric(ci)) list(method = "ncp", distribution = "t")
   out
 }
 
@@ -544,21 +794,24 @@ cohens_f_squared <- function(model, partial = TRUE, ci = 0.9, squared = TRUE,
                                        partial = TRUE,
                                        generalized = FALSE,
                                        ci = 0.9,
+                                       verbose = TRUE,
                                        ...) {
-  if (!isTRUE(partial)) {
+  if (verbose && !isTRUE(partial)) {
     warning(
       "Currently only supports partial ",
       type,
       " squared for this class of objects.",
       call. = FALSE
     )
+    partial <- TRUE
   }
 
-  if (isTRUE(generalized) || is.character(generalized)) {
+  if (verbose && (isTRUE(generalized) || is.character(generalized))) {
     warning(
       "generalized ", type, " squared ",
       "is not supported for this class of object."
     )
+    generalized <- FALSE
   }
 
 
@@ -603,6 +856,10 @@ cohens_f_squared <- function(model, partial = TRUE, ci = 0.9, squared = TRUE,
     out <- .anova_es_model_params(model, f, df_num, df_error, type, ci)
   }
 
+  attr(out, "partial") <- partial
+  attr(out, "generalized") <- generalized
+  attr(out, "ci") <- ci
+  attr(out, "ci_method") <- if (is.numeric(ci)) list(method = "ncp", distribution = "t")
   out
 }
 
@@ -610,126 +867,57 @@ cohens_f_squared <- function(model, partial = TRUE, ci = 0.9, squared = TRUE,
 # Specific models ---------------------------------------------------------
 
 #' @keywords internal
-#' @importFrom parameters model_parameters
-#' @importFrom insight find_predictors
-.anova_es.aovlist <- function(model,
-                              type = c("eta", "omega", "epsilon"),
-                              partial = TRUE,
-                              generalized = FALSE,
-                              ci = 0.9,
-                              ...) {
-  type <- match.arg(type)
+.anova_es.htest <- function(model,
+                            type = c("eta", "omega", "epsilon"),
+                            partial = TRUE,
+                            generalized = FALSE,
+                            ci = 0.9,
+                            verbose = TRUE,
+                            ...){
+  if (!grepl("One-way", model$method))
+    stop("'model' is not a one-way test!", call. = FALSE)
 
-  params <- as.data.frame(parameters::model_parameters(model))
-  params <- params[params$Parameter != "(Intercept)", ]
-  if (!"Residuals" %in% params$Parameter) {
-    stop(
-      "No residuals data found - ",
-      type,
-      " squared can only be computed for simple `aov` models."
+  if (verbose && (partial || isTRUE(generalized) || is.character(generalized))) {
+    txt_type <- ifelse(isTRUE(generalized) || is.character(generalized), "generalized", "partial")
+    message(
+      "For one-way between subjects designs, ", txt_type, " ", type, " squared is equvilant to ", type, " squared.\n",
+      "Returning ", type, " squared."
     )
   }
 
-  values <- .values_aov(params)
-  params <- params[params$Parameter != "Residuals" & !is.na(params$`F`), , drop = FALSE]
-  Sum_Squares_total <- sum(sapply(values, "[[", "Sum_Squares_total"))
-  Sum_Squares_residuals <- sapply(values[params$Group], "[[", "Sum_Squares_residuals")
-  Mean_Square_residuals <- sapply(values[params$Group], "[[", "Mean_Square_residuals")
-  df_residuals <- sapply(values[params$Group], "[[", "df_residuals")
-  ns <- sapply(values[params$Group], "[[", "n")
+  effectsize(model, type = type, ci = ci)
+}
 
+#' @keywords internal
+.anova_es.Anova.mlm <- function(model,
+                                type = c("eta", "omega", "epsilon"),
+                                partial = TRUE,
+                                generalized = FALSE,
+                                ci = 0.9,
+                                verbose = TRUE,
+                                include_intercept = FALSE,
+                                ...) {
+  # ## For the univariate test
+  # model <- summary(mlm1.aov)$univariate.tests
+  # .anova_es.anova(model, type = type,
+  #                 partial = partial,
+  #                 generalized = generalized,
+  #                 ci = ci,
+  #                 verbose = verbose,
+  #                 ...)
 
-  if (type == "eta") {
-    if (isTRUE(generalized) || is.character(generalized)) {
-      ## copied from afex
-      obs <- logical(nrow(params))
-      if (is.character(generalized)) {
-        for (o in generalized) {
-          oi <- grepl(paste0("\\b", o, "\\b"), params$Parameter)
-
-          if (!any(oi)) stop("Observed variable not in data: ", o, call. = FALSE)
-
-          obs <- obs | oi
-        }
-      }
-      obs_SSn1 <- sum(params$Sum_Squares * obs)
-      obs_SSn2 <- params$Sum_Squares * obs
-
-      params$Eta2_generalized <- params$Sum_Squares /
-        (params$Sum_Squares + sum(sapply(values, "[[", "Sum_Squares_residuals")) +
-          obs_SSn1 - obs_SSn2)
-    } else if (!isTRUE(partial)) {
-      params$Eta2 <- params$Sum_Squares / Sum_Squares_total
-    } else {
-      params$Eta2_partial <-
-        params$Sum_Squares /
-          (params$Sum_Squares + Sum_Squares_residuals)
-    }
-  } else if (type == "omega") {
-    SSS_values <- values[[which(names(values) %in% insight::find_predictors(model)[[1]])]]
-    is_within <- !params$Group %in% insight::find_predictors(model)[[1]]
-    Sum_Squares_Subjects <- SSS_values$Sum_Squares_residuals
-    Mean_Squares_Subjects <- SSS_values$Mean_Square_residuals
-
-    # implemented from https://www.jasonfinley.com/tools/OmegaSquaredQuickRef_JRF_3-31-13.pdf
-    if (!isTRUE(partial)) {
-      params$Omega2 <-
-        (params$Sum_Squares - params$df * Mean_Square_residuals) /
-          (Sum_Squares_total + Mean_Squares_Subjects)
-    } else {
-      params$Omega2_partial <-
-        (params$Sum_Squares - params$df * Mean_Square_residuals) /
-          (params$Sum_Squares + is_within * Sum_Squares_residuals +
-            Sum_Squares_Subjects + Mean_Squares_Subjects)
-    }
-  } else if (type == "epsilon") {
-    if (!isTRUE(partial)) {
-      params$Epsilon2 <-
-        (params$Sum_Squares - params$df * Mean_Square_residuals) /
-          Sum_Squares_total
-    } else {
-      params$Epsilon2_partial <-
-        (params$Sum_Squares - params$df * Mean_Square_residuals) /
-          (params$Sum_Squares + Sum_Squares_residuals)
-    }
-  }
-
-  out <- params
-
-  if (!is.null(ci)) {
-    # based on MBESS::ci.R2
-    ES <- pmax(0, out[[ncol(out)]])
-    f <- (ES / out$df) / ((1 - ES) / df_residuals)
-
-    out <- cbind(
-      out,
-      # This really is a generic F_to_R2
-      F_to_eta2(f,
-        out$df,
-        df_residuals,
-        ci = ci
-      )[-1]
-    )
-  }
-
-  out <- out[, colnames(out) %in% c(
-    "Group",
-    "Response",
-    "Parameter",
-    "Eta2_generalized",
-    "Eta2_partial",
-    "Omega2_partial",
-    "Epsilon2_partial",
-    "Eta2",
-    "Omega2",
-    "Epsilon2",
-    "CI",
-    "CI_low",
-    "CI_high"
-  ), drop = FALSE]
-  rownames(out) <- NULL
-
-  out
+  ## For the multivariate test
+  model <- parameters::model_parameters(model, ...)
+  if ("df_num" %in% colnames(model))
+    model$df <- model$df_num
+  if (!include_intercept)
+    model <- model[model$Parameter != "(Intercept)", , drop = FALSE]
+  .anova_es.parameters_model(model, type = type,
+                             partial = partial,
+                             generalized = generalized,
+                             ci = ci,
+                             verbose = verbose,
+                             ...)
 }
 
 #' @keywords internal
@@ -739,6 +927,7 @@ cohens_f_squared <- function(model, partial = TRUE, ci = 0.9, squared = TRUE,
                              partial = TRUE,
                              generalized = FALSE,
                              ci = 0.9,
+                             verbose = TRUE,
                              ...) {
   if (!requireNamespace("lmerTest", quietly = TRUE)) {
     stop(
@@ -759,6 +948,7 @@ cohens_f_squared <- function(model, partial = TRUE, ci = 0.9, squared = TRUE,
                           partial = TRUE,
                           generalized = FALSE,
                           ci = 0.9,
+                          verbose = TRUE,
                           ...) {
   type <- match.arg(type)
   es_fun <- switch(type,
@@ -767,20 +957,22 @@ cohens_f_squared <- function(model, partial = TRUE, ci = 0.9, squared = TRUE,
     epsilon = F_to_epsilon2
   )
 
-  if (!isTRUE(partial)) {
+  if (verbose && !isTRUE(partial)) {
     warning(
       "Currently only supports partial ",
       type,
       " squared for repeated-measures / multi-variate ANOVAs",
       call. = FALSE
     )
+    partial <- TRUE
   }
 
-  if (isTRUE(generalized) || is.character(generalized)) {
+  if (verbose && (isTRUE(generalized) || is.character(generalized))) {
     warning(
       "generalized ", type, " squared ",
       "is not supported for this class of object."
     )
+    generalized <- FALSE
   }
 
   model <- stats::anova(model)
@@ -797,6 +989,10 @@ cohens_f_squared <- function(model, partial = TRUE, ci = 0.9, squared = TRUE,
     )
   )
 
+  attr(out, "ci") <- ci
+  attr(out, "ci_method") <- if (is.numeric(ci)) list(method = "ncp", distribution = "t")
+  attr(out, "partial") <- partial
+  attr(out, "generalized") <- generalized
   out
 }
 
@@ -806,23 +1002,48 @@ cohens_f_squared <- function(model, partial = TRUE, ci = 0.9, squared = TRUE,
                                partial = TRUE,
                                generalized = FALSE,
                                ci = 0.9,
+                               verbose = TRUE,
+                               include_intercept = FALSE,
                                ...) {
   type <- match.arg(type)
+  if (type == "eta" && isTRUE(generalized))
+    generalized <- attr(model$anova_table, "observed")
 
-  if (!requireNamespace("afex", quietly = TRUE)) {
-    stop(
-      "Package 'afex' required for this function to work. ",
-      "Please install it by running `install.packages('afex')`."
-    )
+  # For completely between, covers all
+  if (!inherits(model$Anova, "Anova.mlm")) {
+    out <-
+      .anova_es(
+        model$Anova,
+        type = type,
+        partial = partial,
+        generalized = generalized,
+        ci = ci,
+        verbose = verbose,
+        include_intercept = include_intercept,
+        ...
+      )
+    return(out)
   }
 
+
+
+
+
+
+
   # generalized eta2
-  if (type == "eta" && (isTRUE(generalized) || is.character(generalized))) {
-    if (isTRUE(generalized)) {
-      generalized <- attr(model$anova_table, "observed")
+  if (type == "eta" && is.character(generalized)) {
+    if (!requireNamespace("afex", quietly = TRUE)) {
+      stop(
+        "Package 'afex' required for this function to work. ",
+        "Please install it by running `install.packages('afex')`."
+      )
     }
 
-    aov_tab <- anova(model, es = "ges", observed = generalized, correction = "none")
+    aov_tab <- anova(model, es = "ges",
+                     observed = generalized,
+                     correction = "none",
+                     intercept = include_intercept)
 
     ES <- aov_tab$ges
     df1 <- aov_tab$`num Df`
@@ -847,6 +1068,10 @@ cohens_f_squared <- function(model, partial = TRUE, ci = 0.9, squared = TRUE,
         )[-1]
       )
     }
+    attr(out, "ci") <- ci
+    attr(out, "ci_method") <- if (is.numeric(ci)) list(method = "ncp", distribution = "t")
+    attr(out, "partial") <- partial
+    attr(out, "generalized") <- generalized
     return(out)
   }
 
@@ -858,7 +1083,8 @@ cohens_f_squared <- function(model, partial = TRUE, ci = 0.9, squared = TRUE,
       epsilon = F_to_epsilon2
     )
 
-    aov_tab <- anova(model, es = "none", correction = "none")
+    aov_tab <- anova(model, es = "none", correction = "none",
+                     intercept = include_intercept)
 
     out <- cbind(
       Parameter = rownames(aov_tab),
@@ -868,24 +1094,14 @@ cohens_f_squared <- function(model, partial = TRUE, ci = 0.9, squared = TRUE,
         ci = ci
       )
     )
+    attr(out, "ci") <- ci
+    attr(out, "ci_method") <- if (is.numeric(ci)) list(method = "ncp", distribution = "t")
+    attr(out, "partial") <- partial
+    attr(out, "generalized") <- generalized
     return(out)
   }
 
-  # For between, covers all
-  if (!inherits(model$Anova, "Anova.mlm")) {
-    out <-
-      .anova_es(
-        model$Anova,
-        type = type,
-        partial = FALSE,
-        generalized = FALSE,
-        ci = ci
-      )
-    return(out)
-  }
-
-
-  # If not fully between, covers all
+  # Even if not fully between, covers all
   if (!is.null(model$aov)) {
     out <-
       .anova_es(
@@ -894,12 +1110,15 @@ cohens_f_squared <- function(model, partial = TRUE, ci = 0.9, squared = TRUE,
         partial = partial,
         generalized = FALSE,
         ci = ci,
+        verbose = verbose,
+        include_intercept = include_intercept,
+        ...
       )
     out <- out[, !colnames(out) == "Group"]
     return(out)
   }
 
-  # Error,,, only so much can be done...
+  # Error... only so much can be done...
   if (partial) {
     stop(
       "Cannot get partial Omega squared for mixed-effects 'afex_aov' object when",
@@ -926,6 +1145,7 @@ cohens_f_squared <- function(model, partial = TRUE, ci = 0.9, squared = TRUE,
                           partial = TRUE,
                           generalized = FALSE,
                           ci = 0.9,
+                          verbose = TRUE,
                           ...) {
   if (!inherits(model, "anova.rms")) {
     model <- stats::anova(model)
@@ -939,39 +1159,11 @@ cohens_f_squared <- function(model, partial = TRUE, ci = 0.9, squared = TRUE,
 
   model <- model[rownames(model) != "ERROR", ]
 
-  out <- .anova_es.anova(model, type = type, partial = partial, generalized = generalized, ci = ci)
-  return(out)
+  .anova_es.anova(model, type = type, partial = partial, generalized = generalized, ci = ci, ...)
 }
 
 .anova_es.anova.rms <- .anova_es.rms
 
-
-#' @keywords internal
-#' @importFrom insight model_info
-.cohens_f_delta <- function(model, model2, ci = 0.9, squared = FALSE) {
-  # check
-  if (!inherits(model, "lm") ||
-    !inherits(model2, "lm") ||
-    !insight::model_info(model)$is_linear ||
-    !insight::model_info(model2)$is_linear) {
-    stop("Cohen's f for R2-change only supported for fixed effect linear models.",
-      call. = FALSE
-    )
-  }
-
-  # Anova
-  ANOVA <- anova(model, model2)
-  out <- F_to_f(ANOVA[2, "F"], abs(ANOVA[2, "Df"]), min(ANOVA["Res.Df"]),
-    ci = ci, squared = squared
-  )
-
-  if (requireNamespace("performance")) {
-    R2d <- performance::r2(model)[[1]] - performance::r2(model2)[[1]]
-    out$R2_delta <- abs(R2d)
-  }
-
-  return(out)
-}
 # Utils -------------------------------------------------------------------
 
 #' @keywords internal
