@@ -1,10 +1,9 @@
 #' @param ss_function For Bayesian models, the function used to extract
-#'   sum-of-squares. Uses [`anova()`] by default, but can also be [car::Anova()]
+#'   sum-of-squares. Uses [`anova()`] by default, but can also be `car::Anova()`
 #'   for simple linear models.
 #' @param draws For Bayesian models, an integer indicating the number of draws
 #'   from the posterior predictive distribution to return. Larger numbers take
 #'   longer to run, but provide estimates that are more stable.
-#' @param verbose Show messages / warning about centering.
 #'
 #' @export
 #' @rdname eta_squared
@@ -39,20 +38,24 @@ eta_squared_posterior.stanreg <- function(model,
   }
 
   if (partial && mo_inf$is_mixed) {
-    warning(
-      "Bayesian Partial Eta Squared not supported for mixed models.\n",
-      "Returning Eta Squared instead."
-    )
+    if (verbose) {
+      warning(
+        "Bayesian Partial Eta Squared not supported for mixed models.\n",
+        "Returning Eta Squared instead."
+      )
+    }
     partial <- FALSE
     # would need to account for random effects if present.
     # Too hard right now.
   }
 
-  if (!isFALSE(generalized) && mo_inf$is_mixed) {
-    warning(
-      "Bayesian Generalized Eta Squared not supported for mixed models.\n",
-      "Returning Eta Squared instead."
-    )
+  if ((isTRUE(generalized) || is.character(generalized)) && mo_inf$is_mixed) {
+    if (verbose) {
+      warning(
+        "Bayesian Generalized Eta Squared not supported for mixed models.\n",
+        "Returning Eta Squared instead."
+      )
+    }
     generalized <- FALSE
   }
 
@@ -62,7 +65,7 @@ eta_squared_posterior.stanreg <- function(model,
   resp_name <- insight::find_response(model)
 
   # test centered predictors
-  .all_centered(X)
+  if (verbose) .all_centered(X)
 
   ## 2. get ppd
   ppd <- rstantools::posterior_predict(model,
@@ -94,6 +97,8 @@ eta_squared_posterior.stanreg <- function(model,
   })
 
   res <- do.call("rbind", res)
+  attr(res, "partial") <- partial
+  attr(res, "generalized") <- generalized
   return(res)
 }
 
