@@ -1,15 +1,18 @@
 #' Interpret standardized differences
 #'
-#' Interpretation of standardized differences using different sets of rules of thumb.
+#' Interpretation of standardized differences using different sets of rules of
+#' thumb.
 #'
 #'
 #' @param d,g,delta Value or vector of effect size values.
-#' @param rules Can be `"cohen1988"` (default), `"gignac2016"`, `"sawilowsky2009"` or custom set of [rules()].
+#' @param rules Can be `"cohen1988"` (default), `"gignac2016"`,
+#'   `"sawilowsky2009"`, `"lovakov2021"` or a custom set of [rules()].
 #' @param ... Not directly used.
 #'
 #' @section Rules:
 #'
-#' Rules apply to equally to positive and negative *d*.
+#' Rules apply to equally to positive and negative *d* (i.e., they are given as
+#' absolute values).
 #'
 #' - Cohen (1988) (`"cohen1988"`; default)
 #'   - **d < 0.2** - Very small
@@ -24,6 +27,11 @@
 #'   - **0.8 <= d < 1.2** - Large
 #'   - **1.2 <= d < 2** - Very large
 #'   - **d >= 2** - Huge
+#' - Lovakov & Agadullina (2021) (`"lovakov2021"`)
+#'   - **d < 0.15** - Very small
+#'   - **0.15 <= d < 0.36** - Small
+#'   - **0.36 <= d < 0.65** - Medium
+#'   - **d >= 0.65** - Large
 #' - Gignac & Szodorai (2016) (`"gignac2016"`, based on the [d_to_r()] conversion, see [interpret_r()])
 #'   - **d < 0.2** - Very small
 #'   - **0.2 <= d < 0.41** - Small
@@ -33,9 +41,19 @@
 #' @examples
 #' interpret_d(.02)
 #' interpret_d(c(.5, .02))
+#' interpret_d(.3, rules = "lovakov2021")
 #' @references
-#' - Gignac, G. E., & Szodorai, E. T. (2016). Effect size guidelines for individual differences researchers. Personality and individual differences, 102, 74-78.
-#' - Cohen, J. (1988). Statistical power analysis for the behavioural sciences.
+#' - Lovakov, A., & Agadullina, E. R. (2021). Empirically Derived Guidelines for
+#' Effect Size Interpretation in Social Psychology. European Journal of Social
+#' Psychology.
+#'
+#' - Gignac, G. E., & Szodorai, E. T. (2016). Effect size guidelines for
+#' individual differences researchers. Personality and individual differences,
+#' 102, 74-78.
+#'
+#' - Cohen, J. (1988). Statistical power analysis for the behavioral sciences
+#' (2nd Ed.). New York: Routledge.
+#'
 #' - Sawilowsky, S. S. (2009). New effect size rules of thumb.
 #'
 #' @export
@@ -54,6 +72,10 @@ interpret_d <- function(d, rules = "cohen1988", ...) {
         c("tiny", "very small", "small", "medium", "large", "very large", "huge"),
         name = "sawilowsky2009", right = FALSE
       ),
+      lovakov2021 = rules(c(0.15, 0.36, 0.65),
+        c("very small", "small", "medium", "large"),
+        name = "lovakov2021", right = FALSE
+      ),
       gignac2016 = NA # added for the correct error msg
     )
   )
