@@ -1,7 +1,8 @@
 #' Interpret correlation
 #'
 #' @param r Value or vector of correlation coefficient.
-#' @param rules Can be `"funder2019"` (default), `"gignac2016"`, `"cohen1988"`, `"evans1996"` or custom set of [rules()].
+#' @param rules Can be `"funder2019"` (default), `"gignac2016"`, `"cohen1988"`,
+#'   `"evans1996"`, `"lovakov2021"` or a custom set of [rules()].
 #'
 #' @section Rules:
 #'
@@ -24,6 +25,11 @@
 #'   - **0.1 <= r < 0.3** - Small
 #'   - **0.3 <= r < 0.5** - Moderate
 #'   - **r >= 0.5** - Large
+#' - Lovakov & Agadullina (2021) (`"lovakov2021"`)
+#'   - **r < 0.12** - Very small
+#'   - **0.12 <= r < 0.24** - Small
+#'   - **0.24 <= r < 0.41** - Moderate
+#'   - **r >= 0.41** - Large
 #' - Evans (1996) (`"evans1996"`)
 #'   - **r < 0.2** - Very weak
 #'   - **0.2 <= r < 0.4** - Weak
@@ -34,13 +40,27 @@
 #' @examples
 #' interpret_r(.015)
 #' interpret_r(c(.5, -.02))
+#' interpret_r(.3, rules = "lovakov2021")
 #' @seealso Page 88 of APA's 6th Edition.
 #'
 #' @references
-#' - Funder, D. C., & Ozer, D. J. (2019). Evaluating effect size in psychological research: sense and nonsense. Advances in Methods and Practices in Psychological Science.
-#' - Gignac, G. E., & Szodorai, E. T. (2016). Effect size guidelines for individual differences researchers. Personality and individual differences, 102, 74-78.
-#' - Cohen, J. (1988). Statistical power analysis for the behavioral sciences (2nd Ed.). New York: Routledge.
-#' - Evans, J. D. (1996). Straightforward statistics for the behavioral sciences. Thomson Brooks/Cole Publishing Co.
+#' - Lovakov, A., & Agadullina, E. R. (2021). Empirically Derived Guidelines for
+#' Effect Size Interpretation in Social Psychology. European Journal of Social
+#' Psychology.
+#'
+#' - Funder, D. C., & Ozer, D. J. (2019). Evaluating effect size in
+#' psychological research: sense and nonsense. Advances in Methods and Practices
+#' in Psychological Science.
+#'
+#' - Gignac, G. E., & Szodorai, E. T. (2016). Effect size guidelines for
+#' individual differences researchers. Personality and individual differences,
+#' 102, 74-78.
+#'
+#' - Cohen, J. (1988). Statistical power analysis for the behavioral sciences
+#' (2nd Ed.). New York: Routledge.
+#'
+#' - Evans, J. D. (1996). Straightforward statistics for the behavioral
+#' sciences. Thomson Brooks/Cole Publishing Co.
 #'
 #' @export
 interpret_r <- function(r, rules = "funder2019") {
@@ -62,6 +82,10 @@ interpret_r <- function(r, rules = "funder2019") {
       evans1996 = rules(c(0.2, 0.4, 0.6, 0.8),
         c("very weak", "weak", "moderate", "strong", "very strong"),
         name = "evans1996", right = FALSE
+      ),
+      lovakov2021 = rules(c(0.12, 0.24, 0.41),
+        c("very small", "small", "medium", "large"),
+        name = "lovakov2021", right = FALSE
       )
     )
   )
