@@ -11,11 +11,15 @@
 #'
 #' @inheritSection standardize_parameters Generalized Linear Models
 #' @export
-standardize.default <- function(x, robust = FALSE, two_sd = FALSE, weights = TRUE, verbose = TRUE,
-                                include_response = TRUE, ...) {
+standardize.default <- function(x,
+                                robust = FALSE,
+                                two_sd = FALSE,
+                                weights = TRUE,
+                                verbose = TRUE,
+                                include_response = TRUE,
+                                ...) {
   m_info <- insight::model_info(x)
   data <- insight::get_data(x)
-  resp <- NULL
 
   # for models with specific scale of the response value (e.g. count models
   # with positive integers, or beta with ratio between 0 and 1), we need to
@@ -25,6 +29,8 @@ standardize.default <- function(x, robust = FALSE, two_sd = FALSE, weights = TRU
     resp <- unique(c(insight::find_response(x), insight::find_response(x, combine = FALSE)))
   } else if (include_response && two_sd) {
     resp <- unique(c(insight::find_response(x), insight::find_response(x, combine = FALSE)))
+  } else {
+    resp <- NULL
   }
 
   # Do not standardize weighting-variable, because negative weights will
@@ -41,10 +47,22 @@ standardize.default <- function(x, robust = FALSE, two_sd = FALSE, weights = TRU
   random_group_factor <- insight::find_random(x, flatten = TRUE, split_nested = TRUE)
 
   # standardize data
-
   dont_standardize <- c(resp, weight_variable, random_group_factor)
   do_standardize <- setdiff(colnames(data), dont_standardize)
 
+  # can't std data$var variables
+  # TODO what about "with"?
+  if (any(doller_vars <- grepl("(.*)\\$(.*)", do_standardize))) {
+    doller_vars <- colnames(data)[doller_vars]
+    warning("Unable to standardize variables evaluated in the environment (i.e., not in `data`).\n",
+      "The following variables will not be standardizd:\n\t",
+      paste0(doller_vars, collapse = ", "),
+      call. = FALSE
+    )
+    do_standardize <- setdiff(do_standardize, doller_vars)
+  }
+
+
   if (length(do_standardize)) {
     w <- insight::get_weights(x, na_rm = TRUE)
 
@@ -66,9 +84,7 @@ standardize.default <- function(x, robust = FALSE, two_sd = FALSE, weights = TRU
       dont_standardize <- setdiff(dont_standardize, resp)
     }
   } else {
-    if (verbose) {
-      insight::print_color("No variables could be standardized.\n", "red")
-    }
+    warning("No variables could be standardized.", call. = FALSE)
     return(x)
   }
 
@@ -91,7 +107,7 @@ standardize.default <- function(x, robust = FALSE, two_sd = FALSE, weights = TRU
     })
   }
 
-  if (length(log_terms) > 0 || length(sqrt_terms) > 0) {
+  if (verbose && (length(log_terms) > 0 || length(sqrt_terms) > 0)) {
     message("Formula contains log- or sqrt-terms. See help(\"standardize\") for how such terms are standardized.")
   }
 
@@ -126,7 +142,12 @@ standardize.default <- function(x, robust = FALSE, two_sd = FALSE, weights = TRU
 
 
 #' @export
-standardize.mlm <- function(x, robust = FALSE, two_sd = FALSE, weights = TRUE, verbose = TRUE, ...) {
+standardize.mlm <- function(x,
+                            robust = FALSE,
+                            two_sd = FALSE,
+                            weights = TRUE,
+                            verbose = TRUE,
+                            ...) {
   standardize.default(x,
     robust = robust, two_sd = two_sd, weights = weights, verbose = verbose,
     include_response = FALSE, ...
@@ -135,7 +156,13 @@ standardize.mlm <- function(x, robust = FALSE, two_sd = FALSE, weights = TRUE, v
 
 
 #' @export
-standardize.coxph <- function(x, robust = FALSE, two_sd = FALSE, weights = TRUE, verbose = TRUE, ...) {
+standardize.coxph <- function(x,
+                              robust = FALSE,
+                              two_sd = FALSE,
+                              weights = TRUE,
+                              verbose = TRUE,
+                              ...) {
+
 
   # for some models, the DV cannot be standardized when using
   # "update()", so we only standardize model predictors
@@ -185,8 +212,14 @@ standardize.coxme <- standardize.coxph
 #' @importFrom utils capture.output
 #' @importFrom insight get_data
 #' @importFrom stats update
-standardize.mediate <- function(x, robust = FALSE, two_sd = FALSE, weights = TRUE, verbose = TRUE,
-                                include_response = TRUE, ...) {
+standardize.mediate <- function(x,
+                                robust = FALSE,
+                                two_sd = FALSE,
+                                weights = TRUE,
+                                verbose = TRUE,
+                                include_response = TRUE,
+                                ...) {
+
 
   # models and data
   y <- x$model.y
@@ -240,7 +273,7 @@ standardize.mediate <- function(x, robust = FALSE, two_sd = FALSE, weights = TRU
   #   if (verbose) message("control and treatment values have been rescaled to their standardized scales.")
   # }
 
-  if (!all(c(control.value, treat.value) %in% c(0, 1))) {
+  if (verbose && !all(c(control.value, treat.value) %in% c(0, 1))) {
     warning("control and treat values are not 0 and 1, and have not been re-scaled.",
       "\nInterpret results with caution.",
       call. = FALSE
@@ -281,9 +314,13 @@ standardize.mediate <- function(x, robust = FALSE, two_sd = FALSE, weights = TRU
 
 
 #' @export
-standardize.wbm <- function(x, robust = FALSE, two_sd = FALSE, weights = TRUE, verbose = TRUE, ...) {
-  warning(paste0("Standardization of parameters not possible for models of class '", class(x)[1], "'."), call. = FALSE)
-  x
+standardize.wbm <- function(x,
+                            robust = FALSE,
+                            two_sd = FALSE,
+                            weights = TRUE,
+                            verbose = TRUE,
+                            ...) {
+  stop(paste0("Standardization of parameters not possible for models of class '", class(x)[1], "'."), call. = FALSE)
 }
 
 #' @export
@@ -328,7 +365,7 @@ standardize.wbgee <- standardize.wbm
 #' @keywords internal
 .no_response_standardize <- function(info) {
   # check if model has a response variable that should not be standardized.
-  !info$is_linear | info$family == "inverse.gaussian"
+  !info$is_linear | info$is_censored | info$family == "inverse.gaussian"
 
   ## TODO alternative would be to keep the below line for checking if no std possible
   ##      and then treat response for "Gamma()" or "inverse.gaussian" similar to log-terms
