@@ -74,11 +74,15 @@
 #' ## 2-by-2 tables
 #' ## -------------
 #' (RCT <- matrix(
-#'   c(71,  30,
-#'     50, 100),
+#'   c(
+#'     71, 30,
+#'     50, 100
+#'   ),
 #'   nrow = 2, byrow = TRUE,
-#'   dimnames = list(Diagnosis = c("Sick", "Recovered"),
-#'                   Group = c("Treatment", "Control"))
+#'   dimnames = list(
+#'     Diagnosis = c("Sick", "Recovered"),
+#'     Group = c("Treatment", "Control")
+#'   )
 #' )) # note groups are COLUMNS
 #'
 #' oddsratio(RCT)
@@ -117,8 +121,14 @@ phi <- function(x, y = NULL, ci = 0.95, adjust = FALSE, CI, ...) {
 
   if (inherits(x, "htest")) {
     if (!(grepl("Pearson's Chi-squared", x$method) ||
-          grepl("Chi-squared test for given probabilities", x$method)))
+      grepl("Chi-squared test for given probabilities", x$method))) {
       stop("'x' is not a Chi-squared test!", call. = FALSE)
+    }
+    return(effectsize(x, type = "phi", adjust = adjust, ci = ci))
+  } else if (inherits(x, "BFBayesFactor")) {
+    if (!inherits(x@numerator[[1]], "BFcontingencyTable")) {
+      stop("'x' is not a Chi-squared test!", call. = FALSE)
+    }
     return(effectsize(x, type = "phi", adjust = adjust, ci = ci))
   }
 
@@ -162,8 +172,14 @@ cramers_v <- function(x, y = NULL, ci = 0.95, adjust = FALSE, CI, ...) {
 
   if (inherits(x, "htest")) {
     if (!(grepl("Pearson's Chi-squared", x$method) ||
-          grepl("Chi-squared test for given probabilities", x$method)))
+      grepl("Chi-squared test for given probabilities", x$method))) {
       stop("'x' is not a Chi-squared test!", call. = FALSE)
+    }
+    return(effectsize(x, type = "cramers_v", adjust = adjust, ci = ci))
+  } else if (inherits(x, "BFBayesFactor")) {
+    if (!inherits(x@numerator[[1]], "BFcontingencyTable")) {
+      stop("'x' is not a Chi-squared test!", call. = FALSE)
+    }
     return(effectsize(x, type = "cramers_v", adjust = adjust, ci = ci))
   }
 
@@ -200,13 +216,18 @@ cramers_v <- function(x, y = NULL, ci = 0.95, adjust = FALSE, CI, ...) {
 oddsratio <- function(x, y = NULL, ci = 0.95, log = FALSE, ...) {
   if (inherits(x, "htest")) {
     if (grepl("Pearson's Chi-squared", x$method) ||
-          grepl("Chi-squared test for given probabilities", x$method)) {
+      grepl("Chi-squared test for given probabilities", x$method)) {
       return(effectsize(x, type = "or", log = log, ci = ci))
     } else if (grepl("Fisher's Exact", x$method)) {
       return(effectsize(x, ...))
     } else {
       stop("'x' is not a Chi-squared / Fisher's Exact test!", call. = FALSE)
     }
+  } else if (inherits(x, "BFBayesFactor")) {
+    if (!inherits(x@numerator[[1]], "BFcontingencyTable")) {
+      stop("'x' is not a Chi-squared test!", call. = FALSE)
+    }
+    return(effectsize(x, type = "or", log = log, ci = ci))
   }
 
   res <- suppressWarnings(stats::chisq.test(x, y, ...))
@@ -225,6 +246,7 @@ oddsratio <- function(x, y = NULL, ci = 0.95, log = FALSE, ...) {
 
   res <- data.frame(Odds_ratio = OR)
 
+  ci_method <- NULL
   if (is.numeric(ci)) {
     stopifnot(length(ci) == 1, ci < 1, ci > 0)
     res$CI <- ci
@@ -237,6 +259,8 @@ oddsratio <- function(x, y = NULL, ci = 0.95, log = FALSE, ...) {
 
     res$CI_low <- confs[1]
     res$CI_high <- confs[2]
+
+    ci_method <- list(method = "normal")
   }
 
   if (log) {
@@ -246,6 +270,9 @@ oddsratio <- function(x, y = NULL, ci = 0.95, log = FALSE, ...) {
   }
 
   class(res) <- c("effectsize_table", "see_effectsize_table", class(res))
+  attr(res, "ci") <- ci
+  attr(res, "ci_method") <- ci_method
+  attr(res, "log") <- log
   return(res)
 }
 
@@ -256,8 +283,14 @@ oddsratio <- function(x, y = NULL, ci = 0.95, log = FALSE, ...) {
 riskratio <- function(x, y = NULL, ci = 0.95, log = FALSE, ...) {
   if (inherits(x, "htest")) {
     if (!(grepl("Pearson's Chi-squared", x$method) ||
-          grepl("Chi-squared test for given probabilities", x$method)))
+      grepl("Chi-squared test for given probabilities", x$method))) {
       stop("'x' is not a Chi-squared test!", call. = FALSE)
+    }
+    return(effectsize(x, type = "rr", log = log, ci = ci))
+  } else if (inherits(x, "BFBayesFactor")) {
+    if (!inherits(x@numerator[[1]], "BFcontingencyTable")) {
+      stop("'x' is not a Chi-squared test!", call. = FALSE)
+    }
     return(effectsize(x, type = "rr", log = log, ci = ci))
   }
 
@@ -280,6 +313,7 @@ riskratio <- function(x, y = NULL, ci = 0.95, log = FALSE, ...) {
 
   res <- data.frame(Risk_ratio = RR)
 
+  ci_method <- NULL
   if (is.numeric(ci)) {
     stopifnot(length(ci) == 1, ci < 1, ci > 0)
     res$CI <- ci
@@ -292,6 +326,8 @@ riskratio <- function(x, y = NULL, ci = 0.95, log = FALSE, ...) {
 
     res$CI_low <- confs[1]
     res$CI_high <- confs[2]
+
+    ci_method <- list(method = "normal")
   }
 
   if (log) {
@@ -301,6 +337,9 @@ riskratio <- function(x, y = NULL, ci = 0.95, log = FALSE, ...) {
   }
 
   class(res) <- c("effectsize_table", "see_effectsize_table", class(res))
+  attr(res, "ci") <- ci
+  attr(res, "ci_method") <- ci_method
+  attr(res, "log") <- log
   return(res)
 }
 
@@ -310,8 +349,14 @@ riskratio <- function(x, y = NULL, ci = 0.95, log = FALSE, ...) {
 cohens_h <- function(x, y = NULL, ci = 0.95, ...) {
   if (inherits(x, "htest")) {
     if (!(grepl("Pearson's Chi-squared", x$method) ||
-          grepl("Chi-squared test for given probabilities", x$method)))
+      grepl("Chi-squared test for given probabilities", x$method))) {
       stop("'x' is not a Chi-squared test!", call. = FALSE)
+    }
+    return(effectsize(x, type = "cohens_h", ci = ci))
+  } else if (inherits(x, "BFBayesFactor")) {
+    if (!inherits(x@numerator[[1]], "BFcontingencyTable")) {
+      stop("'x' is not a Chi-squared test!", call. = FALSE)
+    }
     return(effectsize(x, type = "cohens_h", ci = ci))
   }
 
@@ -334,6 +379,7 @@ cohens_h <- function(x, y = NULL, ci = 0.95, ...) {
 
   out <- data.frame(Cohens_h = H)
 
+  ci_method <- NULL
   if (is.numeric(ci)) {
     stopifnot(length(ci) == 1, ci < 1, ci > 0)
 
@@ -344,9 +390,13 @@ cohens_h <- function(x, y = NULL, ci = 0.95, ...) {
     out$CI <- ci
     out$CI_low <- H - Zc * (2 * se_arcsin)
     out$CI_high <- H + Zc * (2 * se_arcsin)
+
+    ci_method <- list(method = "normal")
   }
 
   class(out) <- c("effectsize_table", "see_effectsize_table", class(out))
+  attr(out, "ci") <- ci
+  attr(out, "ci_method") <- ci_method
   return(out)
 }
 
@@ -356,8 +406,9 @@ cohens_h <- function(x, y = NULL, ci = 0.95, ...) {
 #' @importFrom stats complete.cases prop.test
 cohens_g <- function(x, y = NULL, ci = 0.95, ...) {
   if (inherits(x, "htest")) {
-    if (!grepl("McNemar", x$method))
+    if (!grepl("McNemar", x$method)) {
       stop("'x' is not a McNemar test!", call. = FALSE)
+    }
     return(effectsize(x, ci = ci))
   }
 
@@ -391,6 +442,7 @@ cohens_g <- function(x, y = NULL, ci = 0.95, ...) {
 
   out <- data.frame(Cohens_g = g)
 
+  ci_method <- NULL
   if (is.numeric(ci)) {
     n <- sum(b) + sum(c)
     k <- P * n
@@ -404,9 +456,13 @@ cohens_g <- function(x, y = NULL, ci = 0.95, ...) {
     out$CI <- ci
     out$CI_low <- res$conf.int[1] - 0.5
     out$CI_high <- res$conf.int[2] - 0.5
+
+    ci_method <- list(method = "binomial")
   }
 
   class(out) <- c("effectsize_table", "see_effectsize_table", class(out))
+  attr(out, "ci") <- ci
+  attr(out, "ci_method") <- ci_method
   return(out)
 }
 
